@@ -12,15 +12,19 @@ pub(crate) mod cpu_usage;
 pub(crate) mod create_hook_callbacks;
 pub(crate) mod create_read_stream_options;
 pub(crate) mod create_write_stream_options;
+pub(crate) mod crypto_constants;
 pub(crate) mod disconnect_listener;
 pub(crate) mod domain;
 pub(crate) mod errno_exception;
 pub(crate) mod exit_listener;
 pub(crate) mod format_input_path_object;
+pub(crate) mod generate_key_pair_options;
+pub(crate) mod generate_key_pair_sync_return;
 pub(crate) mod get_name_options;
 pub(crate) mod hr_time;
 pub(crate) mod immediate;
 pub(crate) mod inspect_options;
+pub(crate) mod key_object_export_options;
 pub(crate) mod memory_usage;
 pub(crate) mod message_listener;
 pub(crate) mod mkdtemp_sync_options;
@@ -53,10 +57,13 @@ pub(crate) mod readable_stream;
 pub(crate) mod rejection_handled_listener;
 pub(crate) mod remove_listener_listener;
 pub(crate) mod require_resolve;
+pub(crate) mod scrypt_options;
+pub(crate) mod set_aad_options;
 pub(crate) mod signals;
 pub(crate) mod signals_listener;
 pub(crate) mod socket;
 pub(crate) mod stream_transform_options;
+pub(crate) mod stream_writable_options;
 pub(crate) mod timer;
 pub(crate) mod typed_array;
 pub(crate) mod uncaught_exception_listener;
@@ -85,15 +92,19 @@ pub use cpu_usage::*;
 pub use create_hook_callbacks::*;
 pub use create_read_stream_options::*;
 pub use create_write_stream_options::*;
+pub use crypto_constants::*;
 pub use disconnect_listener::*;
 pub use domain::*;
 pub use errno_exception::*;
 pub use exit_listener::*;
 pub use format_input_path_object::*;
+pub use generate_key_pair_options::*;
+pub use generate_key_pair_sync_return::*;
 pub use get_name_options::*;
 pub use hr_time::*;
 pub use immediate::*;
 pub use inspect_options::*;
+pub use key_object_export_options::*;
 pub use memory_usage::*;
 pub use message_listener::*;
 pub use mkdtemp_sync_options::*;
@@ -126,10 +137,13 @@ pub use readable_stream::*;
 pub use rejection_handled_listener::*;
 pub use remove_listener_listener::*;
 pub use require_resolve::*;
+pub use scrypt_options::*;
+pub use set_aad_options::*;
 pub use signals::*;
 pub use signals_listener::*;
 pub use socket::*;
 pub use stream_transform_options::*;
+pub use stream_writable_options::*;
 pub use timer::*;
 pub use typed_array::*;
 pub use uncaught_exception_listener::*;
